@@ -24,13 +24,16 @@
 #' to its \code{RLum} class.
 #'
 #' @param \dots further arguments and graphical parameters that will be passed
-#' to the specific plot functions
+#' to the specific plot functions. The only argument that is supported directly is \code{main}
+#' (setting the plot title). In contrast to the normal behaviour \code{main} can be here provided as
+#' \code{\link{list}} and the arguments in the list will dispatched to the plots if the \code{object}
+#' is of type \code{list} as well.
 #'
 #' @return Returns a plot.
 #'
 #' @note The provided plot output depends on the input object.
 #'
-#' @section Function version: 0.4.0
+#' @section Function version: 0.4.2
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
@@ -59,6 +62,7 @@
 #' plot_RLum(temp)
 #'
 #'
+#' @export
 plot_RLum<- function(
   object,
   ...
@@ -69,31 +73,33 @@ plot_RLum<- function(
   ##check if object is of class RLum
   RLum.dispatcher <- function(object, ...) {
     if (inherits(object, "RLum")) {
+
       ##grep object class
       object.class <- is(object)[1]
 
-      ##select which plot function should be used
-
+      ##select which plot function should be used and call it
       switch (
         object.class,
 
-        RLum.Data.Curve = plot_RLum.Data.Curve(object, ...),
-        RLum.Data.Spectrum = plot_RLum.Data.Spectrum(object, ...),
-        RLum.Data.Image = plot_RLum.Data.Image(object, ...),
-        RLum.Analysis = plot_RLum.Analysis(object, ...),
-        RLum.Results = plot_RLum.Results(object, ...)
+        RLum.Data.Curve = plot_RLum.Data.Curve(object = object, ...),
+        RLum.Data.Spectrum = plot_RLum.Data.Spectrum(object = object, ...),
+        RLum.Data.Image = plot_RLum.Data.Image(object = object, ...),
+        RLum.Analysis = plot_RLum.Analysis(object = object, ...),
+        RLum.Results = plot_RLum.Results(object = object, ...)
 
       )
 
     }else{
       stop(paste0(
-        "[plot_RLum] Sorry, I don't know what to do for object of type '", is(object)[1], "'."
+        "[plot_RLum()] Sorry, I don't know what to do for object of type '", is(object)[1], "'."
       ))
 
     }
 
   }
 
+
+
   # Run dispatcher ------------------------------------------------------------------------------
 
   ##call for the list, if not just proceed as normal
@@ -112,16 +118,56 @@ plot_RLum<- function(
 
     ##(2) check if empty, if empty do nothing ...
     if (length(object.cleaned) != 0) {
-      for (i in 1:length(object.cleaned)) {
-        RLum.dispatcher(object[[i]], ...)
 
+      ## If we iterate over a list, this might be extremly useful to have different plot titles
+      if("main" %in% names(list(...))){
+        if(is(list(...)$main,"list")){
+          main.list <- rep(list(...)$main, length = length(object.cleaned))
+
+        }
+      }
+
+      ##set also mtext, but in a different way
+      if(!"mtext" %in% names(list(...))){
+
+
+        if(is(object[[1]], "RLum.Analysis")){
+          mtext <- paste("Record:", 1:length(object.cleaned))
+
+        }else{
+          mtext <- NULL
+
+        }
+      }else{
+        mtext <- rep(list(...)$mtext, lenth.out = length(object.cleaned))
+
+      }
+
+
+      if(exists("main.list")){
+        ##dispatch objects
+        for (i in 1:length(object.cleaned)) {
+          RLum.dispatcher(object = object[[i]],
+                          main = main.list[[i]],
+                          mtext = mtext[[i]],
+                          ...)
+        }
+      }else{
+        for (i in 1:length(object.cleaned)) {
+
+
+          RLum.dispatcher(object = object[[i]],
+                          mtext = mtext[[i]],
+                          ...)
+        }
 
       }
 
     }
 
   }else{
-    RLum.dispatcher(object, ...)
+    ##dispatch object
+    RLum.dispatcher(object = object, ...)
 
   }
 
