@@ -1270,12 +1270,12 @@ write_R2BIN <- function(
 
 ## ---- DEPRECATED GENERICS
 # .Deprecated in package version 0.5.0
-# .Defunct in 0.5.X
+# .Defunct in 0.5.1
 # Removed in 0.6.0
 #' @noRd
 #' @export
 writeR2BIN <- function(...) {
-  .Deprecated("write_R2BIN")
+  .Defunct("write_R2BIN")
   write_R2BIN(...)
 }
 
